pub unsafe fn zero_out_secbox<T>(secbox: &mut SecBox<T>)Expand description
Overwrite the contents with zeros. This is automatically done in the destructor.
Safety
An all-zero byte-pattern must be a valid value of T in order for this function call to not be
undefined behavior.